@@ -32,11 +32,11 @@ def get_idf_scores():
     return scores
 
 def reduce_sense(sense):
-    bag = set([])
-    bag.update(sense.definition.split(' '))
-    bag.update([ x.name for x in sense.lemmas])
+    bag = set(re.findall(r'\b[A-Za-z]+\b',sense.definition.lower()))
+    for x in sense.lemmas:
+        bag.update(re.findall(r'\b[A-Za-z]+\b',x.name.lower()))
     for e in sense.examples:
-        bag.update(e.split(' '))
+        bag.update(re.findall(r'\b[A-Za-z]+\b',e.lower()))
     return bag
 
 def bag_of_words(sense):
@@ -58,7 +58,7 @@ def bag_of_words(sense):
 def relatedness(sense_one,sense_two):
     bag_one = bag_of_words(sense_one)
     bag_two = bag_of_words(sense_two)
-    return sum([IDF[i] in bag_one & bag_two])
+    return sum([IDF[i] for i in bag_one & bag_two])
 
 def get_semantic_predictability(word_sense,context_senses,debug=False,style='A'):
     if isinstance(word_sense,str):
